# -*- coding: utf-8 -*-
# Generated by Django 1.11.28 on 2021-07-26 12:30
from __future__ import unicode_literals

import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import ishtar_common.models_common
import re


class Migration(migrations.Migration):

    dependencies = [
        ('archaeological_files', '0105_auto_20201204_1442'),
    ]

    operations = [
        migrations.CreateModel(
            name='AgreementType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('label', models.TextField(verbose_name='Label')),
                ('txt_idx', models.TextField(help_text='The slug is the standardized version of the name. It contains only lowercase letters, numbers and hyphens. Each slug must be unique.', unique=True, validators=[django.core.validators.RegexValidator(re.compile('^[-a-zA-Z0-9_]+\\Z', 32), "Enter a valid 'slug' consisting of letters, numbers, underscores or hyphens.", 'invalid')], verbose_name='Textual ID')),
                ('comment', models.TextField(blank=True, default='', verbose_name='Comment')),
                ('available', models.BooleanField(default=True, verbose_name='Available')),
            ],
            options={
                'verbose_name': 'Agreement type - France',
                'verbose_name_plural': 'Agreement types - France',
                'ordering': ('label',),
            },
            bases=(ishtar_common.models_common.Cached, models.Model),
        ),
        migrations.CreateModel(
            name='EquipmentServiceCost',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.SlugField(help_text='The slug is the standardized version of the name. It contains only lowercase letters, numbers and hyphens. Each slug must be unique.', max_length=300, unique=True, verbose_name='Textual ID')),
                ('service_provider', models.CharField(blank=True, default='', max_length=200, verbose_name='Service provider')),
                ('flat_rate', models.BooleanField(default=False, verbose_name='Flat rate')),
                ('unitary_cost', models.FloatField(blank=True, null=True, verbose_name='Unitary cost')),
                ('unit', models.CharField(blank=True, choices=[('D', 'days'), ('W', 'weeks'), ('M', 'months'), ('L', 'linear meter')], max_length=1, null=True, verbose_name='Unit')),
                ('specificity', models.CharField(blank=True, default='', max_length=200, verbose_name='Specificity')),
                ('default_quantity_by_day', models.IntegerField(default=0, verbose_name='Default quantity by day')),
                ('order', models.IntegerField(default=10, verbose_name='Order')),
                ('available', models.BooleanField(default=True, verbose_name='Available')),
            ],
            options={
                'verbose_name': 'Equipment/service cost',
                'verbose_name_plural': 'Equipment/service costs',
                'ordering': ('order', 'equipment_service_type__label'),
            },
        ),
        migrations.CreateModel(
            name='EquipmentServiceType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('label', models.TextField(verbose_name='Label')),
                ('txt_idx', models.TextField(help_text='The slug is the standardized version of the name. It contains only lowercase letters, numbers and hyphens. Each slug must be unique.', unique=True, validators=[django.core.validators.RegexValidator(re.compile('^[-a-zA-Z0-9_]+\\Z', 32), "Enter a valid 'slug' consisting of letters, numbers, underscores or hyphens.", 'invalid')], verbose_name='Textual ID')),
                ('comment', models.TextField(blank=True, default='', verbose_name='Comment')),
                ('available', models.BooleanField(default=True, verbose_name='Available')),
                ('order', models.IntegerField(default=10, verbose_name='Order')),
            ],
            options={
                'verbose_name': 'Equipment/service type',
                'verbose_name_plural': 'Equipment/service types',
                'ordering': ('order', 'label'),
            },
            bases=(ishtar_common.models_common.Cached, models.Model),
        ),
        migrations.CreateModel(
            name='GenericEquipmentServiceType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('label', models.TextField(verbose_name='Label')),
                ('txt_idx', models.TextField(help_text='The slug is the standardized version of the name. It contains only lowercase letters, numbers and hyphens. Each slug must be unique.', unique=True, validators=[django.core.validators.RegexValidator(re.compile('^[-a-zA-Z0-9_]+\\Z', 32), "Enter a valid 'slug' consisting of letters, numbers, underscores or hyphens.", 'invalid')], verbose_name='Textual ID')),
                ('comment', models.TextField(blank=True, default='', verbose_name='Comment')),
                ('available', models.BooleanField(default=True, verbose_name='Available')),
                ('order', models.IntegerField(default=10, verbose_name='Order')),
            ],
            options={
                'verbose_name': 'Generic equipment type',
                'verbose_name_plural': 'Generic equipment types',
                'ordering': ('order', 'label'),
            },
            bases=(ishtar_common.models_common.Cached, models.Model),
        ),
        migrations.CreateModel(
            name='Job',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('label', models.TextField(verbose_name='Label')),
                ('txt_idx', models.TextField(help_text='The slug is the standardized version of the name. It contains only lowercase letters, numbers and hyphens. Each slug must be unique.', unique=True, validators=[django.core.validators.RegexValidator(re.compile('^[-a-zA-Z0-9_]+\\Z', 32), "Enter a valid 'slug' consisting of letters, numbers, underscores or hyphens.", 'invalid')], verbose_name='Textual ID')),
                ('comment', models.TextField(blank=True, default='', verbose_name='Comment')),
                ('available', models.BooleanField(default=True, verbose_name='Available')),
                ('ground_daily_cost', models.FloatField(blank=True, null=True, verbose_name='Ground daily cost')),
                ('daily_cost', models.FloatField(blank=True, null=True, verbose_name='Daily cost')),
                ('permanent_contract', models.NullBooleanField(verbose_name='Permanent contract')),
                ('default_daily_need_on_ground', models.FloatField(default=0, verbose_name='Def. daily number on ground')),
                ('default_daily_need', models.FloatField(default=0, verbose_name='Def. daily number')),
                ('order', models.IntegerField(default=10, verbose_name='Order')),
                ('child', models.ForeignKey(blank=True, help_text='Auto-add this job when a parent is added', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='parents', to='archaeological_files.Job', verbose_name='Child')),
            ],
            options={
                'verbose_name': 'Job',
                'verbose_name_plural': 'Jobs',
                'ordering': ('order', '-permanent_contract', 'label'),
            },
            bases=(ishtar_common.models_common.Cached, models.Model),
        ),
        migrations.CreateModel(
            name='OperationTypeForRoyalties',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('label', models.TextField(verbose_name='Label')),
                ('txt_idx', models.TextField(help_text='The slug is the standardized version of the name. It contains only lowercase letters, numbers and hyphens. Each slug must be unique.', unique=True, validators=[django.core.validators.RegexValidator(re.compile('^[-a-zA-Z0-9_]+\\Z', 32), "Enter a valid 'slug' consisting of letters, numbers, underscores or hyphens.", 'invalid')], verbose_name='Textual ID')),
                ('comment', models.TextField(blank=True, default='', verbose_name='Comment')),
                ('available', models.BooleanField(default=True, verbose_name='Available')),
                ('increase_coefficient', models.FloatField(default=1, verbose_name='Increase coefficient')),
                ('increased_final_value', models.FloatField(default=1, verbose_name='Increased final value')),
                ('category', models.PositiveSmallIntegerField(default=1, validators=[django.core.validators.MinValueValidator(1), django.core.validators.MaxValueValidator(5)], verbose_name='Category')),
            ],
            options={
                'verbose_name': 'Operation type for royalties - France',
                'verbose_name_plural': 'Operation types for royalties - France',
                'ordering': ('id',),
            },
            bases=(ishtar_common.models_common.Cached, models.Model),
        ),
        migrations.CreateModel(
            name='PreventiveFileEquipmentServiceCost',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('quantity_by_day_planned', models.FloatField(blank=True, null=True, verbose_name='Quantity by day - planned')),
                ('days_planned', models.FloatField(blank=True, null=True, verbose_name='Days - planned')),
                ('quantity_by_day_worked', models.FloatField(blank=True, null=True, verbose_name='Quantity by day - worked')),
                ('days_worked', models.FloatField(blank=True, null=True, verbose_name='Days - worked')),
                ('equipment_service_cost', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='archaeological_files.EquipmentServiceCost')),
            ],
            options={
                'ordering': ('equipment_service_cost',),
            },
        ),
        migrations.CreateModel(
            name='PreventiveFileGroundJob',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('man_by_day_planned', models.FloatField(blank=True, null=True, verbose_name='Man by day - planned')),
                ('days_planned', models.FloatField(blank=True, null=True, verbose_name='Days - planned')),
                ('man_by_day_worked', models.FloatField(blank=True, null=True, verbose_name='Man by day - worked')),
                ('days_worked', models.FloatField(blank=True, null=True, verbose_name='Days - worked')),
            ],
            options={
                'ordering': ('job',),
            },
        ),
        migrations.CreateModel(
            name='PreventiveFileJob',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('man_by_day_planned', models.FloatField(blank=True, null=True, verbose_name='Man by day - planned')),
                ('days_planned', models.FloatField(blank=True, null=True, verbose_name='Days - planned')),
                ('man_by_day_worked', models.FloatField(blank=True, null=True, verbose_name='Man by day - worked')),
                ('days_worked', models.FloatField(blank=True, null=True, verbose_name='Days - worked')),
            ],
            options={
                'ordering': ('job',),
            },
        ),
        migrations.AddField(
            model_name='file',
            name='execution_report_date',
            field=models.DateField(blank=True, null=True, verbose_name='Execution report date'),
        ),
        migrations.AddField(
            model_name='file',
            name='ground_end_date',
            field=models.DateField(blank=True, null=True, verbose_name='Ground end date'),
        ),
        migrations.AddField(
            model_name='file',
            name='ground_start_date',
            field=models.DateField(blank=True, null=True, verbose_name='Ground start date'),
        ),
        migrations.AddField(
            model_name='file',
            name='linear_meter',
            field=models.IntegerField(blank=True, null=True, verbose_name='Linear meter'),
        ),
        migrations.AddField(
            model_name='file',
            name='start_date',
            field=models.DateField(blank=True, null=True, verbose_name='Start date'),
        ),
        migrations.AddField(
            model_name='file',
            name='study_period',
            field=models.CharField(blank=True, default='', max_length=200, verbose_name='Study period'),
        ),
        migrations.AddField(
            model_name='historicalfile',
            name='execution_report_date',
            field=models.DateField(blank=True, null=True, verbose_name='Execution report date'),
        ),
        migrations.AddField(
            model_name='historicalfile',
            name='ground_end_date',
            field=models.DateField(blank=True, null=True, verbose_name='Ground end date'),
        ),
        migrations.AddField(
            model_name='historicalfile',
            name='ground_start_date',
            field=models.DateField(blank=True, null=True, verbose_name='Ground start date'),
        ),
        migrations.AddField(
            model_name='historicalfile',
            name='linear_meter',
            field=models.IntegerField(blank=True, null=True, verbose_name='Linear meter'),
        ),
        migrations.AddField(
            model_name='historicalfile',
            name='start_date',
            field=models.DateField(blank=True, null=True, verbose_name='Start date'),
        ),
        migrations.AddField(
            model_name='historicalfile',
            name='study_period',
            field=models.CharField(blank=True, default='', max_length=200, verbose_name='Study period'),
        ),
        migrations.AlterField(
            model_name='file',
            name='end_date',
            field=models.DateField(blank=True, null=True, verbose_name='End date'),
        ),
        migrations.AlterField(
            model_name='historicalfile',
            name='end_date',
            field=models.DateField(blank=True, null=True, verbose_name='End date'),
        ),
        migrations.AddField(
            model_name='preventivefilejob',
            name='file',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='jobs', to='archaeological_files.File'),
        ),
        migrations.AddField(
            model_name='preventivefilejob',
            name='job',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='archaeological_files.Job'),
        ),
        migrations.AddField(
            model_name='preventivefilegroundjob',
            name='file',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='ground_jobs', to='archaeological_files.File'),
        ),
        migrations.AddField(
            model_name='preventivefilegroundjob',
            name='job',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='archaeological_files.Job'),
        ),
        migrations.AddField(
            model_name='preventivefileequipmentservicecost',
            name='file',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='equipment_costs', to='archaeological_files.File'),
        ),
        migrations.AddField(
            model_name='equipmentservicetype',
            name='generic_equipment_type',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='archaeological_files.GenericEquipmentServiceType', verbose_name='Generic type'),
        ),
        migrations.AddField(
            model_name='equipmentservicecost',
            name='equipment_service_type',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='archaeological_files.EquipmentServiceType', verbose_name='Equipment/Service'),
        ),
        migrations.AddField(
            model_name='equipmentservicecost',
            name='parent',
            field=models.ForeignKey(blank=True, help_text='Auto-add this cost when a parent is added', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='children', to='archaeological_files.EquipmentServiceType', verbose_name='Parent'),
        ),
        migrations.AddField(
            model_name='file',
            name='operation_type_for_royalties',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='archaeological_files.OperationTypeForRoyalties', verbose_name='Operation type for royalties'),
        ),
        migrations.AddField(
            model_name='file',
            name='type_of_agreement',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='archaeological_files.AgreementType', verbose_name='Type of agreement'),
        ),
        migrations.AddField(
            model_name='historicalfile',
            name='operation_type_for_royalties',
            field=models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='archaeological_files.OperationTypeForRoyalties', verbose_name='Operation type for royalties'),
        ),
        migrations.AddField(
            model_name='historicalfile',
            name='type_of_agreement',
            field=models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='archaeological_files.AgreementType', verbose_name='Type of agreement'),
        ),
    ]
