# Generated by Django 2.2.24 on 2024-03-07 17:52

from django.db import migrations
from django.db.models.functions import Length
from ishtar_common.data import FRENCH_STATES, FRENCH_TOM_STATES


def migrate(apps, __):
    Area = apps.get_model('ishtar_common', 'Area')
    Department = apps.get_model('ishtar_common', 'Department')
    State = apps.get_model('ishtar_common', 'State')
    Town = apps.get_model('ishtar_common', 'Town')

    if not State.objects.filter(label="Nord-Pas-de-Calais").count():
        # already OK or not french
        return

    State.objects.filter(pk__isnull=False).delete()
    Area.objects.filter(txt_idx__startswith="dep-").delete()
    Area.objects.filter(txt_idx__startswith="state-").delete()

    for lbl, code, departments in (FRENCH_STATES + FRENCH_TOM_STATES):
        state = State.objects.create(label=lbl, number=code)
        state_area = Area.objects.create(label=lbl, txt_idx=f'state-{code}')
        for dep_code in departments:
            q = Department.objects.filter(number=dep_code)
            if not q.count():
                print(f"{dep_code} department is missing")
                continue
            dep = q.all()[0]
            dep.state = state
            dep.save()
            dep_area = Area.objects.create(label=dep.label, txt_idx=f'dep-{dep.number}')
            dep_area.parent = state_area
            dep_area.save()
            dep_area.towns.clear()
            q2 = Town.objects.annotate(insee_len=Length('numero_insee')).filter(
                numero_insee__startswith=dep_code, insee_len=5)
            dep_area.towns.add(*list(q2.all()))


class Migration(migrations.Migration):

    dependencies = [
        ('ishtar_common', '0240_state_number_max_len'),
    ]

    operations = [
        migrations.RunPython(migrate)
    ]
